@@ -3,7 +3,7 @@ from django import apps
 
 
 class ReportAppConfig(apps.AppConfig):
-    label = 'Slick Reporting'
+    verbose_name = 'Slick Reporting'
     name = 'slick_reporting'
 
     def ready(self):
