@@ -2,10 +2,9 @@ from __future__ import unicode_literals
 
 import datetime
 import logging
-from inspect import isclass
-
 from django.core.exceptions import ImproperlyConfigured, FieldDoesNotExist
 from django.db.models import Q, ForeignKey
+from inspect import isclass
 
 from .app_settings import SLICK_REPORTING_DEFAULT_CHARTS_ENGINE
 from .fields import SlickReportField
@@ -57,6 +56,11 @@ class ReportGenerator(object):
        Example:
        columns = ['product_id', '__time_series__', 'col_b']
        Same is true with __crosstab__ 
+    
+    You can customize aspects of the column by adding it as a tuple like this 
+        ('field_name', dict(verbose_name=_('My Enhanced Verbose_name'))
+        
+         
      """
 
     time_series_pattern = ''
@@ -202,14 +206,12 @@ class ReportGenerator(object):
             except IndexError:
                 raise ImproperlyConfigured(
                     f'Can not find group_by field:{self.group_by} in report_model {self.report_model} ')
-            self.focus_field_as_key = self.group_by_field
             if '__' not in self.group_by:
                 self.group_by_field_attname = self.group_by_field.attname
             else:
                 self.group_by_field_attname = self.group_by
 
         else:
-            self.focus_field_as_key = None
             self.group_by_field_attname = None
 
         # doc_types = form.get_doc_type_plus_minus_lists()
@@ -249,7 +251,8 @@ class ReportGenerator(object):
                     concrete_fields = [f.name for f in self.group_by_field.related_model._meta.concrete_fields]
                     # add database columns that are not already in concrete_fields
                     final_fields = concrete_fields + list(set(self.get_database_columns()) - set(concrete_fields))
-                    self.main_queryset = self.group_by_field.related_model.objects.filter(pk__in=ids).values(*final_fields)
+                    self.main_queryset = self.group_by_field.related_model.objects.filter(pk__in=ids).values(
+                        *final_fields)
                 else:
                     self.main_queryset = self.main_queryset.distinct().values(self.group_by_field_attname)
         else:
@@ -335,6 +338,13 @@ class ReportGenerator(object):
                 report_class.init_preparation(q_filters, date_filter)
                 self.report_fields_classes[name] = report_class
 
+    @staticmethod
+    def get_primary_key_name(model):
+        for field in model._meta.fields:
+            if field.primary_key:
+                return field.attname
+        return ''
+
     def _get_record_data(self, obj, columns):
         """
         the function is run for every obj in the main_queryset
@@ -343,12 +353,15 @@ class ReportGenerator(object):
         :return: a dict object containing all needed data
         """
 
-        # todo , if columns are empty for whatever reason this will throw an error
-        display_link = self.list_display_links or columns[0]
         data = {}
         group_by_val = None
         if self.group_by:
-            column_data = obj.get(self.group_by_field_attname, obj.get('id'))
+            if self.group_by_field.related_model and '__' not in self.group_by:
+                primary_key_name = self.get_primary_key_name(self.group_by_field.related_model)
+            else:
+                primary_key_name = self.group_by_field_attname
+
+            column_data = obj.get(primary_key_name, obj.get('id'))
             group_by_val = str(column_data)
 
         for window, window_cols in columns:
@@ -374,8 +387,6 @@ class ReportGenerator(object):
 
                 else:
                     data[name] = obj.get(name, '')
-                # if self.group_by and name in display_link:
-                #     data[name] = make_linkable_field(self.group_by_field.related_model, group_by_val, data[name])
         return data
 
     def get_report_data(self):
@@ -411,7 +422,10 @@ class ReportGenerator(object):
         """
         group_by_model = None
         if group_by:
-            group_by_field = [x for x in report_model._meta.get_fields() if x.name == group_by.split('__')[0]][0]
+            try:
+                group_by_field = [x for x in report_model._meta.get_fields() if x.name == group_by.split('__')[0]][0]
+            except IndexError:
+                raise ImproperlyConfigured(f"Could not find {group_by} in {report_model}")
             if group_by_field.is_relation:
                 group_by_model = group_by_field.related_model
             else:
@@ -419,15 +433,19 @@ class ReportGenerator(object):
 
         parsed_columns = []
         for col in columns:
+            options = {}
+            if type(col) is tuple:
+                col, options = col
+
             if col in ['__time_series__', '__crosstab__']:
                 #     These are placeholder not real computation field
                 continue
 
             magic_field_class = None
-            attr = None
+            attribute_field = None
 
             if type(col) is str:
-                attr = getattr(cls, col, None)
+                attribute_field = getattr(cls, col, None)
             elif issubclass(col, SlickReportField):
                 magic_field_class = col
 
@@ -436,12 +454,11 @@ class ReportGenerator(object):
             except KeyError:
                 magic_field_class = None
 
-            if attr:
-                # todo Add testing here
+            if attribute_field:
                 col_data = {'name': col,
-                            'verbose_name': getattr(attr, 'verbose_name', col),
+                            'verbose_name': getattr(attribute_field, 'verbose_name', col),
                             # 'type': 'method',
-                            'ref': attr,
+                            'ref': attribute_field,
                             'type': 'text'
                             }
             elif magic_field_class:
@@ -473,6 +490,7 @@ class ReportGenerator(object):
                             'ref': field,
                             'type': field.get_internal_type()
                             }
+            col_data.update(options)
             parsed_columns.append(col_data)
         return parsed_columns
 
@@ -704,4 +722,3 @@ class ReportGenerator(object):
             x['engine_name'] = x.get('engine_name', SLICK_REPORTING_DEFAULT_CHARTS_ENGINE)
             output.append(x)
         return output
-
